==> zio-aws-databrew_2.13-5.17.155.1-sources.jar: zio/aws/databrew/model/DescribeRecipeRequest.scala <==
package zio.aws.databrew.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.databrew.model.primitives.{RecipeVersion, RecipeName}
import scala.jdk.CollectionConverters._
final case class DescribeRecipeRequest(
    name: RecipeName,
    recipeVersion: Option[RecipeVersion] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest = {
    import DescribeRecipeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest
      .builder()
      .name(RecipeName.unwrap(name): java.lang.String)
      .optionallyWith(
        recipeVersion.map(value =>
          RecipeVersion.unwrap(value): java.lang.String
        )
      )(_.recipeVersion)
      .build()
  }
  def asReadOnly: zio.aws.databrew.model.DescribeRecipeRequest.ReadOnly =
    zio.aws.databrew.model.DescribeRecipeRequest.wrap(buildAwsValue())
}
object DescribeRecipeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databrew.model.DescribeRecipeRequest =
      zio.aws.databrew.model
        .DescribeRecipeRequest(name, recipeVersion.map(value => value))
    def name: RecipeName
    def recipeVersion: Option[RecipeVersion]
    def getName: ZIO[Any, Nothing, RecipeName] = ZIO.succeed(name)
    def getRecipeVersion: ZIO[Any, AwsError, RecipeVersion] =
      AwsError.unwrapOptionField("recipeVersion", recipeVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest
  ) extends zio.aws.databrew.model.DescribeRecipeRequest.ReadOnly {
    override val name: RecipeName =
      zio.aws.databrew.model.primitives.RecipeName(impl.name())
    override val recipeVersion: Option[RecipeVersion] = scala
      .Option(impl.recipeVersion())
      .map(value => zio.aws.databrew.model.primitives.RecipeVersion(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest
  ): zio.aws.databrew.model.DescribeRecipeRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-databrew_2.13-5.17.295.14-sources.jar: zio/aws/databrew/model/DescribeRecipeRequest.scala <==
package zio.aws.databrew.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.databrew.model.primitives.{RecipeVersion, RecipeName}
import scala.jdk.CollectionConverters._
final case class DescribeRecipeRequest(
    name: RecipeName,
    recipeVersion: Optional[RecipeVersion] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest = {
    import DescribeRecipeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest
      .builder()
      .name(RecipeName.unwrap(name): java.lang.String)
      .optionallyWith(
        recipeVersion.map(value =>
          RecipeVersion.unwrap(value): java.lang.String
        )
      )(_.recipeVersion)
      .build()
  }
  def asReadOnly: zio.aws.databrew.model.DescribeRecipeRequest.ReadOnly =
    zio.aws.databrew.model.DescribeRecipeRequest.wrap(buildAwsValue())
}
object DescribeRecipeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databrew.model.DescribeRecipeRequest =
      zio.aws.databrew.model
        .DescribeRecipeRequest(name, recipeVersion.map(value => value))
    def name: RecipeName
    def recipeVersion: Optional[RecipeVersion]
    def getName: ZIO[Any, Nothing, RecipeName] = ZIO.succeed(name)
    def getRecipeVersion: ZIO[Any, AwsError, RecipeVersion] =
      AwsError.unwrapOptionField("recipeVersion", recipeVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest
  ) extends zio.aws.databrew.model.DescribeRecipeRequest.ReadOnly {
    override val name: RecipeName =
      zio.aws.databrew.model.primitives.RecipeName(impl.name())
    override val recipeVersion: Optional[RecipeVersion] = zio.aws.core.internal
      .optionalFromNullable(impl.recipeVersion())
      .map(value => zio.aws.databrew.model.primitives.RecipeVersion(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.databrew.model.DescribeRecipeRequest
  ): zio.aws.databrew.model.DescribeRecipeRequest.ReadOnly = new Wrapper(impl)
}
